@@ -43,9 +43,18 @@ class TestStuff(unittest.TestCase):
             ("jd", "git-pull-request"),
             gpr.get_github_user_repo_from_url(
                 "https://github.com/jd/git-pull-request.git"))
-        self.assertRaises(ValueError,
-                          gpr.get_github_user_repo_from_url,
-                          "https://foobar.com/jd/git-pull-request.git")
+        self.assertEqual(
+            ("jd", "git-pull-request"),
+            gpr.get_github_user_repo_from_url(
+                "git@github.com:jd/git-pull-request.git"))
+        self.assertEqual(
+            ("jd", "git-pull-request"),
+            gpr.get_github_user_repo_from_url(
+                "git://github.com/jd/git-pull-request.git"))
+        self.assertEqual(
+            ("jd", "git-pull-request"),
+            gpr.get_github_user_repo_from_url(
+                "https://example.com/jd/git-pull-request.git"))
 
 
 class TestGitCommand(fixtures.TestWithFixtures):
